==> scorchful-0.15.5%2B1.21.4-sources.jar: com/github/thedeathlycow/scorchful/registry/tag/SBiomeTags.java <==
package com.github.thedeathlycow.scorchful.registry.tag;

import com.github.thedeathlycow.scorchful.Scorchful;
import net.minecraft.class_1959;
import net.minecraft.class_6862;
import net.minecraft.class_7924;

public class SBiomeTags {

    public static final class_6862<class_1959> HUMID_BIOMES = SBiomeTags.register("humid_biomes");

    public static final class_6862<class_1959> IS_NEVER_WARM_TEMPERATURE = SBiomeTags.register("temperature/is_never_warm");

    public static final class_6862<class_1959> HAS_SAND_STORMS = SBiomeTags.register("has_sand_storms");

    public static final class_6862<class_1959> HAS_REGULAR_SAND_STORMS = SBiomeTags.register("has_regular_sand_storms");

    public static final class_6862<class_1959> HAS_RED_SAND_STORMS = SBiomeTags.register("has_red_sand_storms");

    public static final class_6862<class_1959> HAS_FEATURE_CRIMSON_LILY_PATCH = SBiomeTags.register("has_feature/crimson_lily_patch");
    public static final class_6862<class_1959> HAS_FEATURE_SPARSE_CRIMSON_LILY_PATCH = SBiomeTags.register("has_feature/sparse_crimson_lily_patch");

    public static final class_6862<class_1959> HEAT_VISION_HUSK = SBiomeTags.register("heat_vision/husk");
    public static final class_6862<class_1959> HEAT_VISION_BOAT = SBiomeTags.register("heat_vision/boat");
    public static final class_6862<class_1959> HEAT_VISION_POPPY = SBiomeTags.register("heat_vision/poppy");
    public static final class_6862<class_1959> HEAT_VISION_BLUE_ORCHID = SBiomeTags.register("heat_vision/blue_orchid");
    public static final class_6862<class_1959> HEAT_VISION_SALMON = SBiomeTags.register("heat_vision/salmon");
    public static final class_6862<class_1959> HEAT_VISION_COD = SBiomeTags.register("heat_vision/cod");
    public static final class_6862<class_1959> HEAT_VISION_SQUID = SBiomeTags.register("heat_vision/squid");

    static class_6862<class_1959> register(String id) {
        return class_6862.method_40092(class_7924.field_41236, Scorchful.id(id));
    }

    private SBiomeTags() {

    }

}

==> scorchful-0.15.8%2B1.21.1-sources.jar: com/github/thedeathlycow/scorchful/registry/tag/SBiomeTags.java <==
package com.github.thedeathlycow.scorchful.registry.tag;

import com.github.thedeathlycow.scorchful.Scorchful;
import net.minecraft.class_1959;
import net.minecraft.class_6862;
import net.minecraft.class_7924;

public class SBiomeTags {

    public static final class_6862<class_1959> HUMID_BIOMES = SBiomeTags.register("humid_biomes");

    public static final class_6862<class_1959> IS_NEVER_WARM_TEMPERATURE = SBiomeTags.register("temperature/is_never_warm");

    public static final class_6862<class_1959> HAS_SAND_STORMS = SBiomeTags.register("has_sand_storms");

    public static final class_6862<class_1959> HAS_REGULAR_SAND_STORMS = SBiomeTags.register("has_regular_sand_storms");

    public static final class_6862<class_1959> HAS_RED_SAND_STORMS = SBiomeTags.register("has_red_sand_storms");
    public static final class_6862<class_1959> HAS_PINK_SAND_STORMS = SBiomeTags.register("has_pink_sand_storms");

    public static final class_6862<class_1959> HAS_FEATURE_CRIMSON_LILY_PATCH = SBiomeTags.register("has_feature/crimson_lily_patch");
    public static final class_6862<class_1959> HAS_FEATURE_SPARSE_CRIMSON_LILY_PATCH = SBiomeTags.register("has_feature/sparse_crimson_lily_patch");

    public static final class_6862<class_1959> HEAT_VISION_HUSK = SBiomeTags.register("heat_vision/husk");
    public static final class_6862<class_1959> HEAT_VISION_BOAT = SBiomeTags.register("heat_vision/boat");
    public static final class_6862<class_1959> HEAT_VISION_POPPY = SBiomeTags.register("heat_vision/poppy");
    public static final class_6862<class_1959> HEAT_VISION_BLUE_ORCHID = SBiomeTags.register("heat_vision/blue_orchid");
    public static final class_6862<class_1959> HEAT_VISION_SALMON = SBiomeTags.register("heat_vision/salmon");
    public static final class_6862<class_1959> HEAT_VISION_COD = SBiomeTags.register("heat_vision/cod");
    public static final class_6862<class_1959> HEAT_VISION_SQUID = SBiomeTags.register("heat_vision/squid");

    static class_6862<class_1959> register(String id) {
        return class_6862.method_40092(class_7924.field_41236, Scorchful.id(id));
    }

    private SBiomeTags() {

    }

}
